@@ -2,7 +2,6 @@ import os
 
 from django.core.mail import EmailMultiAlternatives
 from django.utils import timezone
-from django.utils.encoding import force_text
 
 from pymess.backend.emails import EmailBackend
 from pymess.models import EmailMessage
@@ -29,9 +28,9 @@ class SMTPEmailBackend(EmailBackend):
             )
         try:
             email_message.send()
-            self.update_message_after_sending(message, state=EmailMessage.STATE.SENT, sent_at=timezone.now())
+            self._update_message_after_sending(message, state=EmailMessage.STATE.SENT, sent_at=timezone.now())
         except Exception as ex:
-            self.update_message_after_sending(message, state=EmailMessage.STATE.ERROR_NOT_SENT, error=force_text(ex))
+            self._update_message_after_sending_error(message, error=str(ex))
             # Do not re-raise caught exception. We do not know exact exception to catch so we catch them all
             # and log them into database. Re-raise exception causes transaction rollback (lost of information about
             # exception).
